==> haskell-vector-space-0.16-147.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-8MH1S7DeKAo96rq0gSQeIM
key:                  vector-space-0.16-8MH1S7DeKAo96rq0gSQeIM
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  326538a6bd34514ebf5a0db3a7c0394b
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-space-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-8MH1S7DeKAo96rq0gSQeIM
depends:
    Boolean-0.2.4-H5MVF6tNJ5XDePp84MxQlJ
    MemoTrie-0.6.11-EzCPS0AcENCFqJcGrA4JYn
    NumInstances-1.4-AzcscTGrj16D5vmkq7ja0z base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-space-0.16-148-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-GbLmlBuAiEkG8668H1gfyA
key:                  vector-space-0.16-GbLmlBuAiEkG8668H1gfyA
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  1985a49fce0fdd1eae71ebb9912e1831
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-space-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-GbLmlBuAiEkG8668H1gfyA
depends:
    Boolean-0.2.4-H5MVF6tNJ5XDePp84MxQlJ
    MemoTrie-0.6.11-JBrVOshtmKn292FiNTA9B
    NumInstances-1.4-AzcscTGrj16D5vmkq7ja0z base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
